Sequences are phased using PHASE. Input and output for PHASE are automatically intraconverted to and from sequence file formats using SeqPHASE. The two are conveniently invoked using ConvPhase.

PHASE: | http://stephenslab.uchicago.edu/phase/download.html
SeqPHASE: | https://github.com/eeg-ebe/SeqPHASE
ConvPhase: | https://github.com/iTaxoTools/ConvPhase

[1] Stephens, M., Smith, N., and Donnelly, P. (2001). A new statistical method for haplotype reconstruction from population data. American Journal of Human Genetics, 68, 978--989.
[2] Stephens, M., and Donnelly, P. (2003). A comparison of Bayesian methods for haplotype reconstruction from population genotype data. American Journal of Human Genetics, 73:1162-1169.
[3] Flot (2010) SeqPHASE: a web tool for interconverting PHASE input/output files and FASTA sequence alignments Molecular Ecology Ressources 10 (1): 162-166.